import { ArrayWrapper } from './array';
import { MapWrapper } from './map';
import { ObjectWrapper } from './object';
import { SetWrapper } from './set';
export declare type Lifted<T> = T extends Wrapper<infer W> ? LiftedValue<W> : LiftedValue<T>;
declare type AtomicObject = Function | Promise<any> | Date | RegExp | Boolean | Number | String;
declare type LiftedValue<T> = T extends AtomicObject ? T : T extends ReadonlyArray<infer E> ? ArrayWrapper<E> : T extends ReadonlyMap<infer K, infer V> ? MapWrapper<K, V> : T extends ReadonlySet<infer E> ? SetWrapper<E> : T extends Date ? Wrapper<Date> : T extends string ? Wrapper<string> : T extends number ? Wrapper<number> : T extends boolean ? Wrapper<boolean> : T extends object ? ObjectWrapper<T> : never;
/** Wraps an Object, Array, Map or Set to provide a richer API. Unwrap with .value() **/
declare type Lift = <T>(obj: T) => Lifted<T>;
declare const lift: Lift;
export default lift;
export declare function getValue<A>(input: A | Wrapper<A>): A;
export interface Wrapper<T> {
    value(): T;
}
export declare function pipe<T, R>(this: Wrapper<T>, func: (object: T) => R): Lifted<R>;
