import { Draft } from './immupdate';
import { pipe } from './lift';
/** A Map wrapper providing extra functionalities and more chaining opportunities */
export declare class MapWrapper<K, V> {
    private _value;
    constructor(_value: ReadonlyMap<K, V>);
    private _isLiftWrapper;
    value(): ReadonlyMap<K, V>;
    clone(): MapWrapper<K, V>;
    private _clone;
    /**
     * Sets a new key/value.
     */
    set(key: K, value: V): MapWrapper<K, V>;
    /**
     * Deletes a key/value.
     */
    delete(key: K): MapWrapper<K, V>;
    /**
     * Clears the map.
     */
    clear(): MapWrapper<K, V>;
    /**
     * Maps this Map's keys and values, unless void or undefined is returned, in which case the entry is filtered.
     */
    collect<KK, VV>(iterator: (key: K, value: V) => [KK, VV] | undefined | void): MapWrapper<KK, VV>;
    /**
     * Filters this Map's keys and values by aplying a predicate to all values and refine its type.
     */
    filter<VV extends V>(predicate: (key: K, value: V) => value is VV): MapWrapper<K, VV>;
    /**
     * Filters this Map's keys and values.
     */
    filter(predicate: (key: K, value: V) => boolean): MapWrapper<K, V>;
    /**
     * Maps this map's value.
     */
    mapValues<VV>(mapFunction: (value: V) => VV): MapWrapper<K, VV>;
    /**
     * Make mutable modifications to a draft then return a new Map.
     */
    update(updateFunction: (draft: Draft<ReadonlyMap<K, V>>) => void): MapWrapper<K, V>;
    pipe: typeof pipe;
    toArray(): import("./array").ArrayWrapper<[K, V]>;
}
